==> haskell-retrie-0.1.1.1-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-retrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 retrie
version:              0.1.1.1
visibility:           public
id:                   retrie-0.1.1.1-LmD7UP74eG6HDO8BqF6ZsP
key:                  retrie-0.1.1.1-LmD7UP74eG6HDO8BqF6ZsP
license:              MIT
copyright:            Copyright (c) Facebook, Inc. and its affiliates.
maintainer:           Andrew Farmer <anfarmer@fb.com>
author:               Andrew Farmer <anfarmer@fb.com>
homepage:             https://github.com/facebookincubator/retrie
synopsis:             A powerful, easy-to-use codemodding tool for Haskell.
description:
    Retrie is a tool for codemodding Haskell. Key goals include:

    * Speed: Efficiently rewrite in large (>1 million line) codebases.
    * Safety: Avoids large classes of codemod-related errors.
    * Ease-of-use: Haskell syntax instead of regular expressions. No hand-rolled AST traversals.

    This package provides a command-line tool (@retrie@) and a library
    ("Retrie") for making equational edits to Haskell code.

    Please see the [README](#readme) for examples and usage.

category:             Development
abi:                  5a90b4a04a7db9d8214930feafefdfff
exposed:              True
exposed-modules:
    Retrie Retrie.AlphaEnv Retrie.CPP Retrie.Context Retrie.Debug
    Retrie.ExactPrint Retrie.ExactPrint.Annotated Retrie.Expr
    Retrie.Fixity Retrie.FreeVars Retrie.GHC Retrie.GroundTerms
    Retrie.Monad Retrie.Options Retrie.PatternMap.Bag
    Retrie.PatternMap.Class Retrie.PatternMap.Instances Retrie.Pretty
    Retrie.Quantifiers Retrie.Query Retrie.Replace Retrie.Rewrites
    Retrie.Rewrites.Function Retrie.Rewrites.Rules
    Retrie.Rewrites.Types Retrie.Run Retrie.SYB Retrie.Subst
    Retrie.Substitution Retrie.Types Retrie.Universe Retrie.Util

import-dirs:          /usr/lib/ghc-8.10.4/site-local/retrie-0.1.1.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/retrie-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/retrie-0.1.1.1
hs-libraries:         HSretrie-0.1.1.1-LmD7UP74eG6HDO8BqF6ZsP
depends:
    ansi-terminal-0.11-LgP8qDXSNhY9o8ci2eucZ9
    async-2.2.3-bRJqoep3gj749cy8sss28 base-4.14.1.0
    bytestring-0.10.12.0 containers-0.6.2.1
    data-default-0.7.1.1-DVZWGRf90hqGebpGTaPvOV directory-1.3.6.0
    filepath-1.4.2.1 ghc-8.10.4
    ghc-exactprint-0.6.3.4-JCGKsbWYXlU3fLDQuuLnHu mtl-2.2.2
    optparse-applicative-0.16.1.0-6BS7yrijROrLnaIn4WCKlt
    process-1.6.9.0 random-shuffle-0.0.4-2SOKxrwPfqcEXdeb1Z6J5P
    syb-0.7.2.1-6T61ufUYzPEC9ZKKBvLLoy text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-HtLybBXdm0X81lurKYn063

haddock-interfaces:   /usr/share/doc/haskell-retrie/html/retrie.haddock
haddock-html:         /usr/share/doc/haskell-retrie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-retrie-0.1.1.1-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-retrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 retrie
version:              0.1.1.1
visibility:           public
id:                   retrie-0.1.1.1-CI4PY1fndkWFW1SIctDjWz
key:                  retrie-0.1.1.1-CI4PY1fndkWFW1SIctDjWz
license:              MIT
copyright:            Copyright (c) Facebook, Inc. and its affiliates.
maintainer:           Andrew Farmer <anfarmer@fb.com>
author:               Andrew Farmer <anfarmer@fb.com>
homepage:             https://github.com/facebookincubator/retrie
synopsis:             A powerful, easy-to-use codemodding tool for Haskell.
description:
    Retrie is a tool for codemodding Haskell. Key goals include:

    * Speed: Efficiently rewrite in large (>1 million line) codebases.
    * Safety: Avoids large classes of codemod-related errors.
    * Ease-of-use: Haskell syntax instead of regular expressions. No hand-rolled AST traversals.

    This package provides a command-line tool (@retrie@) and a library
    ("Retrie") for making equational edits to Haskell code.

    Please see the [README](#readme) for examples and usage.

category:             Development
abi:                  6ac687241bd389a225001ecdb178853e
exposed:              True
exposed-modules:
    Retrie Retrie.AlphaEnv Retrie.CPP Retrie.Context Retrie.Debug
    Retrie.ExactPrint Retrie.ExactPrint.Annotated Retrie.Expr
    Retrie.Fixity Retrie.FreeVars Retrie.GHC Retrie.GroundTerms
    Retrie.Monad Retrie.Options Retrie.PatternMap.Bag
    Retrie.PatternMap.Class Retrie.PatternMap.Instances Retrie.Pretty
    Retrie.Quantifiers Retrie.Query Retrie.Replace Retrie.Rewrites
    Retrie.Rewrites.Function Retrie.Rewrites.Rules
    Retrie.Rewrites.Types Retrie.Run Retrie.SYB Retrie.Subst
    Retrie.Substitution Retrie.Types Retrie.Universe Retrie.Util

import-dirs:          /usr/lib/ghc-8.10.4/site-local/retrie-0.1.1.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/retrie-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/retrie-0.1.1.1
hs-libraries:         HSretrie-0.1.1.1-CI4PY1fndkWFW1SIctDjWz
depends:
    ansi-terminal-0.11-sYFHbiAEH84KFYZWhhTVC
    async-2.2.3-6cp1PlFsKQm7WcAjMY1Y60 base-4.14.1.0
    bytestring-0.10.12.0 containers-0.6.2.1
    data-default-0.7.1.1-DVZWGRf90hqGebpGTaPvOV directory-1.3.6.0
    filepath-1.4.2.1 ghc-8.10.4
    ghc-exactprint-0.6.4-DcOeysiI5WV4dbjJ4g5aiH mtl-2.2.2
    optparse-applicative-0.16.1.0-AZy0evZYndIFSfRXN7doN9
    process-1.6.9.0 random-shuffle-0.0.4-AVfjCiJkJDF7q3ClTQSenp
    syb-0.7.2.1-1IAm6Pw4N3X6UTXXRC2m9l text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-Dm1EWWGKu5F1HgehuVxZbu

haddock-interfaces:   /usr/share/doc/haskell-retrie/html/retrie.haddock
haddock-html:         /usr/share/doc/haskell-retrie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
